package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsRecordInspect;

/**
 * 巡检记录Service接口
 * 
 * @author Open Platform
 * @date 2024-01-16
 */
public interface IDmsRecordInspectService 
{
    /**
     * 查询巡检记录
     * 
     * @param recordInspectId 巡检记录主键
     * @return 巡检记录
     */
    public DmsRecordInspect selectDmsRecordInspectByRecordInspectId(Long recordInspectId);

    /**
     * 查询巡检记录列表
     * 
     * @param dmsRecordInspect 巡检记录
     * @return 巡检记录集合
     */
    public List<DmsRecordInspect> selectDmsRecordInspectList(DmsRecordInspect dmsRecordInspect);

    /**
     * 新增巡检记录
     * 
     * @param dmsRecordInspect 巡检记录
     * @return 结果
     */
    public int insertDmsRecordInspect(DmsRecordInspect dmsRecordInspect);

    /**
     * 修改巡检记录
     * 
     * @param dmsRecordInspect 巡检记录
     * @return 结果
     */
    public int updateDmsRecordInspect(DmsRecordInspect dmsRecordInspect);

    /**
     * 批量删除巡检记录
     * 
     * @param recordInspectIds 需要删除的巡检记录主键集合
     * @return 结果
     */
    public int deleteDmsRecordInspectByRecordInspectIds(Long[] recordInspectIds);

    /**
     * 删除巡检记录信息
     * 
     * @param recordInspectId 巡检记录主键
     * @return 结果
     */
    public int deleteDmsRecordInspectByRecordInspectId(Long recordInspectId);
}
